`backup` module
***************

Fabric tasks
------------

.. autofunction:: django_fabfile.backup.backup_instance
.. autofunction:: django_fabfile.backup.backup_instances_by_tag
.. autofunction:: django_fabfile.backup.delete_broken_snapshots
.. autofunction:: django_fabfile.backup.rsync_mountpoints
.. autofunction:: django_fabfile.backup.rsync_region
.. autofunction:: django_fabfile.backup.rsync_snapshot
.. autofunction:: django_fabfile.backup.trim_snapshots

Internals
---------

.. automodule:: django_fabfile.backup
   :members:
